==> php54-owncloud-8.0.3.tgz: share/owncloud/apps/files/l10n/en_GB.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Storage not available",
    "Storage invalid" : "Storage invalid",
    "Unknown error" : "Unknown error",
    "Could not move %s - File with this name already exists" : "Could not move %s - File with this name already exists",
    "Could not move %s" : "Could not move %s",
    "Permission denied" : "Permission denied",
    "File name cannot be empty." : "File name cannot be empty.",
    "\"%s\" is an invalid file name." : "\"%s\" is an invalid file name.",
    "Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." : "Invalid name: '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed.",
    "The target folder has been moved or deleted." : "The target folder has been moved or deleted.",
    "The name %s is already used in the folder %s. Please choose a different name." : "The name %s is already used in the folder %s. Please choose a different name.",
    "Not a valid source" : "Not a valid source",
    "Server is not allowed to open URLs, please check the server configuration" : "Server is not allowed to open URLs, please check the server configuration",
    "The file exceeds your quota by %s" : "The file exceeds your quota by %s",
    "Error while downloading %s to %s" : "Error whilst downloading %s to %s",
    "Error when creating the file" : "Error when creating the file",
    "Folder name cannot be empty." : "Folder name cannot be empty.",
    "Error when creating the folder" : "Error when creating the folder",
    "Unable to set upload directory." : "Unable to set upload directory.",
    "Invalid Token" : "Invalid Token",
    "No file was uploaded. Unknown error" : "No file was uploaded. Unknown error",
    "There is no error, the file uploaded with success" : "There is no error, the file uploaded successfully",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "The uploaded file exceeds the upload_max_filesize directive in php.ini: ",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form",
    "The uploaded file was only partially uploaded" : "The uploaded file was only partially uploaded",
    "No file was uploaded" : "No file was uploaded",
    "Missing a temporary folder" : "Missing a temporary folder",
    "Failed to write to disk" : "Failed to write to disk",
    "Not enough storage available" : "Not enough storage available",
    "Upload failed. Could not find uploaded file" : "Upload failed. Could not find uploaded file",
    "Upload failed. Could not get file info." : "Upload failed. Could not get file info.",
    "Invalid directory." : "Invalid directory.",
    "Files" : "Files",
    "All files" : "All files",
    "Favorites" : "Favourites",
    "Home" : "Home",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Unable to upload {filename} as it is a directory or has 0 bytes",
    "Total file size {size1} exceeds upload limit {size2}" : "Total file size {size1} exceeds upload limit {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Not enough free space, you are uploading {size1} but only {size2} is left",
    "Upload cancelled." : "Upload cancelled.",
    "Could not get result from server." : "Could not get result from server.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "File upload is in progress. Leaving the page now will cancel the upload.",
    "URL cannot be empty" : "URL cannot be empty",
    "{new_name} already exists" : "{new_name} already exists",
    "Could not create file" : "Could not create file",
    "Could not create folder" : "Could not create folder",
    "Error fetching URL" : "Error fetching URL",
    "Rename" : "Rename",
    "Delete" : "Delete",
    "Disconnect storage" : "Disconnect storage",
    "Unshare" : "Unshare",
    "Download" : "Download",
    "Select" : "Select",
    "Pending" : "Pending",
    "Unable to determine date" : "Unable to determine date",
    "Error moving file." : "Error moving file.",
    "Error moving file" : "Error moving file",
    "Error" : "Error",
    "Could not rename file" : "Could not rename file",
    "Error deleting file." : "Error deleting file.",
    "No entries in this folder match '{filter}'" : "No entries in this folder match '{filter}'",
    "Name" : "Name",
    "Size" : "Size",
    "Modified" : "Modified",
    "_%n folder_::_%n folders_" : ["%n folder","%n folders"],
    "_%n file_::_%n files_" : ["%n file","%n files"],
    "You don’t have permission to upload or create files here" : "You don’t have permission to upload or create files here",
    "_Uploading %n file_::_Uploading %n files_" : ["Uploading %n file","Uploading %n files"],
    "\"{name}\" is an invalid file name." : "\"{name}\" is an invalid file name.",
    "Your storage is full, files can not be updated or synced anymore!" : "Your storage is full, files can not be updated or synced anymore!",
    "Your storage is almost full ({usedSpacePercent}%)" : "Your storage is almost full ({usedSpacePercent}%)",
    "Encryption App is enabled but your keys are not initialized, please log-out and log-in again" : "Encryption App is enabled but your keys are not initialised, please log-out and log-in again",
    "Invalid private key for Encryption App. Please update your private key password in your personal settings to recover access to your encrypted files." : "Invalid private key for Encryption App. Please update your private key password in your personal settings to recover access to your encrypted files.",
    "Encryption was disabled but your files are still encrypted. Please go to your personal settings to decrypt your files." : "Encryption was disabled but your files are still encrypted. Please go to your personal settings to decrypt your files.",
    "_matches '{filter}'_::_match '{filter}'_" : ["matches '{filter}'","match '{filter}'"],
    "{dirs} and {files}" : "{dirs} and {files}",
    "Favorited" : "Favourited",
    "Favorite" : "Favourite",
    "%s could not be renamed as it has been deleted" : "%s could not be renamed as it has been deleted",
    "%s could not be renamed" : "%s could not be renamed",
    "Upload (max. %s)" : "Upload (max. %s)",
    "File handling" : "File handling",
    "Maximum upload size" : "Maximum upload size",
    "max. possible: " : "max. possible: ",
    "Save" : "Save",
    "Settings" : "Settings",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>",
    "New" : "New",
    "New text file" : "New text file",
    "Text file" : "Text file",
    "New folder" : "New folder",
    "Folder" : "Folder",
    "From link" : "From link",
    "Upload" : "Upload",
    "Cancel upload" : "Cancel upload",
    "No files yet" : "No files yet",
    "Upload some content or sync with your devices!" : "Upload some content or sync with your devices!",
    "No entries found in this folder" : "No entries found in this folder",
    "Select all" : "Select all",
    "Upload too large" : "Upload too large",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "The files you are trying to upload exceed the maximum size for file uploads on this server.",
    "Files are being scanned, please wait." : "Files are being scanned, please wait.",
    "Currently scanning" : "Currently scanning",
    "No favorites" : "No favourites",
    "Files and folders you mark as favorite will show up here" : "Files and folders you mark as favourite will show up here"
},
"nplurals=2; plural=(n != 1);");

==> php54-owncloud-8.1.0.tgz: share/owncloud/apps/files/l10n/en_GB.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Storage not available",
    "Storage invalid" : "Storage invalid",
    "Unknown error" : "Unknown error",
    "Could not move %s - File with this name already exists" : "Could not move %s - File with this name already exists",
    "Could not move %s" : "Could not move %s",
    "Permission denied" : "Permission denied",
    "The target folder has been moved or deleted." : "The target folder has been moved or deleted.",
    "The name %s is already used in the folder %s. Please choose a different name." : "The name %s is already used in the folder %s. Please choose a different name.",
    "Error when creating the file" : "Error when creating the file",
    "Error when creating the folder" : "Error when creating the folder",
    "Unable to set upload directory." : "Unable to set upload directory.",
    "Invalid Token" : "Invalid Token",
    "No file was uploaded. Unknown error" : "No file was uploaded. Unknown error",
    "There is no error, the file uploaded with success" : "There is no error, the file uploaded successfully",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "The uploaded file exceeds the upload_max_filesize directive in php.ini: ",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form",
    "The uploaded file was only partially uploaded" : "The uploaded file was only partially uploaded",
    "No file was uploaded" : "No file was uploaded",
    "Missing a temporary folder" : "Missing a temporary folder",
    "Failed to write to disk" : "Failed to write to disk",
    "Not enough storage available" : "Not enough storage available",
    "Upload failed. Could not find uploaded file" : "Upload failed. Could not find uploaded file",
    "Upload failed. Could not get file info." : "Upload failed. Could not get file info.",
    "Invalid directory." : "Invalid directory.",
    "Files" : "Files",
    "All files" : "All files",
    "Favorites" : "Favourites",
    "Home" : "Home",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Unable to upload {filename} as it is a directory or has 0 bytes",
    "Total file size {size1} exceeds upload limit {size2}" : "Total file size {size1} exceeds upload limit {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Not enough free space, you are uploading {size1} but only {size2} is left",
    "Upload cancelled." : "Upload cancelled.",
    "Could not get result from server." : "Could not get result from server.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "File upload is in progress. Leaving the page now will cancel the upload.",
    "{new_name} already exists" : "{new_name} already exists",
    "Could not create file" : "Could not create file",
    "Could not create folder" : "Could not create folder",
    "Rename" : "Rename",
    "Delete" : "Delete",
    "Disconnect storage" : "Disconnect storage",
    "Unshare" : "Unshare",
    "No permission to delete" : "No permission to delete",
    "Download" : "Download",
    "Select" : "Select",
    "Pending" : "Pending",
    "Unable to determine date" : "Unable to determine date",
    "Error moving file." : "Error moving file.",
    "Error moving file" : "Error moving file",
    "Error" : "Error",
    "Could not rename file" : "Could not rename file",
    "Error deleting file." : "Error deleting file.",
    "No entries in this folder match '{filter}'" : "No entries in this folder match '{filter}'",
    "Name" : "Name",
    "Size" : "Size",
    "Modified" : "Modified",
    "_%n folder_::_%n folders_" : ["%n folder","%n folders"],
    "_%n file_::_%n files_" : ["%n file","%n files"],
    "You don’t have permission to upload or create files here" : "You don’t have permission to upload or create files here",
    "_Uploading %n file_::_Uploading %n files_" : ["Uploading %n file","Uploading %n files"],
    "\"{name}\" is an invalid file name." : "\"{name}\" is an invalid file name.",
    "File name cannot be empty." : "File name cannot be empty.",
    "Your storage is full, files can not be updated or synced anymore!" : "Your storage is full, files can not be updated or synced anymore!",
    "Your storage is almost full ({usedSpacePercent}%)" : "Your storage is almost full ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["matches '{filter}'","match '{filter}'"],
    "{dirs} and {files}" : "{dirs} and {files}",
    "Favorited" : "Favourited",
    "Favorite" : "Favourite",
    "An error occurred while trying to update the tags" : "An error occurred whilst trying to update the tags",
    "A new file or folder has been <strong>created</strong>" : "A new file or folder has been <strong>created</strong>",
    "A file or folder has been <strong>changed</strong>" : "A file or folder has been <strong>changed</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limit notifications about creation and changes to your <strong>favourite files</strong> <em>(Stream only)</em>",
    "A file or folder has been <strong>deleted</strong>" : "A file or folder has been <strong>deleted</strong>",
    "A file or folder has been <strong>restored</strong>" : "A file or folder has been <strong>restored</strong>",
    "You created %1$s" : "You created %1$s",
    "%2$s created %1$s" : "%2$s created %1$s",
    "%1$s was created in a public folder" : "%1$s was created in a public folder",
    "You changed %1$s" : "You changed %1$s",
    "%2$s changed %1$s" : "%2$s changed %1$s",
    "You deleted %1$s" : "You deleted %1$s",
    "%2$s deleted %1$s" : "%2$s deleted %1$s",
    "You restored %1$s" : "You restored %1$s",
    "%2$s restored %1$s" : "%2$s restored %1$s",
    "%s could not be renamed as it has been deleted" : "%s could not be renamed as it has been deleted",
    "%s could not be renamed" : "%s could not be renamed",
    "Upload (max. %s)" : "Upload (max. %s)",
    "File handling" : "File handling",
    "Maximum upload size" : "Maximum upload size",
    "max. possible: " : "max. possible: ",
    "Save" : "Save",
    "Can not be edited from here due to insufficient permissions." : "Can not be edited from here due to insufficient permissions.",
    "Settings" : "Settings",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>",
    "New" : "New",
    "New text file" : "New text file",
    "Text file" : "Text file",
    "New folder" : "New folder",
    "Folder" : "Folder",
    "Upload" : "Upload",
    "Cancel upload" : "Cancel upload",
    "No files in here" : "No files in here",
    "Upload some content or sync with your devices!" : "Upload some content or sync with your devices!",
    "No entries found in this folder" : "No entries found in this folder",
    "Select all" : "Select all",
    "Upload too large" : "Upload too large",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "The files you are trying to upload exceed the maximum size for file uploads on this server.",
    "Files are being scanned, please wait." : "Files are being scanned, please wait.",
    "Currently scanning" : "Currently scanning",
    "No favorites" : "No favourites",
    "Files and folders you mark as favorite will show up here" : "Files and folders you mark as favourite will show up here"
},
"nplurals=2; plural=(n != 1);");
